Module baseline
shadowhare
0.9.0
Module baseline
Module Items
Structs
In crate shadowhare
shadowhare
Module
baseline
Structs

Baseline
Persisted baseline — the known set of findings at a point in time. CI fails only on findings whose fingerprint is NOT in the baseline.