pub struct Baseline {
pub schema_version: String,
pub fingerprints: HashSet<String>,
}Expand description
Persisted baseline — the known set of findings at a point in time. CI fails only on findings whose fingerprint is NOT in the baseline.
Fields
schema_version: Stringfingerprints: HashSet<String>Set of finding fingerprints recorded at baseline time.
Implementations
Sourceimpl Baseline
impl Baseline
pub fn load(path: &Path) -> Result<Self, AnalyzerError>
pub fn save(&self, path: &Path) -> Result<(), AnalyzerError>
pub fn update_from_findings(&mut self, findings: &[Finding])
Sourcepub fn new_findings<'a>(&self, findings: &'a [Finding]) -> Vec<&'a Finding>
pub fn new_findings<'a>(&self, findings: &'a [Finding]) -> Vec<&'a Finding>
Returns only findings whose fingerprint is NOT in the baseline.
pub fn is_new(&self, finding: &Finding) -> bool